@@ -7,8 +7,7 @@ from importlib.metadata import PackageNotFoundError, version
 try:
     __version__ = version("greendeploy-cli")
 except PackageNotFoundError:
-    # package is not installed
-    pass
+    __version__ = "0.0.0"
 
 
 import logging
